#
# spec file for package python-heat-cfntools
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-heat-cfntools
Version:        1.4.2
Release:        4.1
Summary:        Tools required to be installed on Heat provisioned cloud instances
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://www.openstack.org/
Source:         https://files.pythonhosted.org/packages/source/h/heat-cfntools/heat-cfntools-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module boto >= 2.12.0}
BuildRequires:  %{python_module mock >= 1.0}
BuildRequires:  %{python_module pbr >= 0.6}
BuildRequires:  %{python_module psutil >= 1.1.1}
BuildRequires:  %{python_module six >= 1.9.0}
BuildRequires:  %{python_module testrepository >= 0.0.18}
BuildRequires:  %{python_module testtools >= 0.9.34}
# /SECTION
BuildRequires:  fdupes
Requires:       python-boto >= 2.12.0
Requires:       python-pbr >= 0.6
Requires:       python-psutil >= 1.1.1
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%python_subpackages

%description
cfn-init   -
             Reads the AWS::CloudFormation::Init for the instance resource,
             installs packages, and starts services
cfn-signal -
             Waits for an application to be ready before continuing, ie:
             supporting the WaitCondition feature
cfn-hup    -
             Handle updates from the UpdateStack CloudFormation API call

%prep
%setup -q -n heat-cfntools-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%ifpython2
python2 setup.py test
%endif

%files %{python_files}
%doc AUTHORS ChangeLog LICENSE README.rst
%python3_only %{_bindir}/cfn-create-aws-symlinks
%python3_only %{_bindir}/cfn-get-metadata
%python3_only %{_bindir}/cfn-hup
%python3_only %{_bindir}/cfn-init
%python3_only %{_bindir}/cfn-push-stats
%python3_only %{_bindir}/cfn-signal
%{python_sitelib}/*

%changelog
* Mon Feb 19 2018 dmueller@suse.com
- update to 1.4.2:
  * Remove argparse from requirements
  * Trivial: Remove vim header from source files
  * py26/py33 is no longer supported by Infra's CI
  * remove python 2.6 trove classifier
  * Put py34 first in the env order of tox
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Deprecated tox -downloadcache option removed
  * Don't run commands given as list on shell
- convert to singlespec
* Wed May 24 2017 dmueller@suse.com
- explicitly build man pages after pbr update
* Sun Oct  4 2015 tbechtold@suse.com
- update to 1.4.1:
  * Convert all internal commands to list
  * Use seteuid instead of su to control privileges
  * Revert "Fix cfntools command injection"
  * Activate pep8 check that _ is imported
  * Fix cfntools command injection
  * Fix unit tests
  * Fix typos in cfn scripts
  * Add --insecure/-k option to cfn-signal
  * README changes to make release_notes.py happy
  * Ported tests from mox3 to mock to support Python >= 3.3
  * Python 3 compatibility
  * Support dnf when specified or yum is missing
  * Fix RST syntax errors/warnings in README.rst
  * Fixes cfn-hup hooks functionality
  * Workflow documentation is now in infra-manual
- adjust Requires according to requirements.txt
* Mon Sep 22 2014 dmueller@suse.com
- update to 1.2.8:
  * Change wget to curl for using both of them is redundant
  * Fix cfn_helper test for random hash seed
  * Update for psutil version
  * Add res_last_path to store last metadata of a resource
  * Update sysvinit function to support ubuntu
  * Add support for package install via zypper
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.7.8.g8ef88a6:
  * Change wget to curl for using both of them is redundant
* Fri Aug 29 2014 dmueller@suse.com
- enable building of html docs
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.7.7.g2e54467:
  * Fix cfn_helper test for random hash seed
* Thu Jul 24 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.7.6.g3d1236d:
  * Update for psutil version
* Thu Jun 19 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.7.5.g9bd9604:
  * Add res_last_path to store last metadata of a resource
  * Update sysvinit function to support ubuntu
  * Add support for package install via zypper
  1.2.7
* Tue Apr 29 2014 dmueller@suse.com
- add python-setuptools requires
* Thu Apr 24 2014 dmueller@suse.com
- require cron, curl
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.19.gcd39c89:
  * Manually sync requirements
* Wed Apr  9 2014 dmueller@suse.com
- Update to version heat-cfntools-1.2.6.18.g331dc7f:
  * Switch over to mox3
* Mon Apr  7 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.16.g9d1909c:
  * Remove tox locale overrides
  * Support building wheels (PEP-427)
* Fri Mar 28 2014 speilicke@suse.com
- Correct obsoletes after some version updates
* Mon Mar 24 2014 dmueller@suse.com
- remove dependency on hacking
* Sun Mar 23 2014 dmueller@suse.com
- run create-aws-compat-symlinks in post install
* Fri Mar  7 2014 speilicke@suse.com
- Add python_requires source service
- Fix build requirements
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.12.g31da8a4:
  * Support of ignoreErrors for commands
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.10.g4ece05a:
  * cfn-signal provides a unique default id
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.9.ga61e221:
  * Log stdout and stderr on non-zero exit status
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version heat-cfntools-1.2.6.7.ga6db3e6:
  * Log curl stderr on non-zero exit status
  * Sync with global requirements
  * Fix logging in cfn-init and cfn-signal
  * Config files should be non-executable
  * Only run yum install once per package block
  * Add basic yum and apt package install tests
  1.2.6
  * Use on-demand yum metadata caching in cfn-init
  * cfn-hup manpage fix s/deamon/daemon typo
  * Implement -k option for cfn-get-metadata
  * Change cfn-signal option --exit to --exit-code
  * Add argparse into requirements
  * Support array values in command
  * Pass cwd and env to test command
  1.2.5
  * Sync with global requirements
  * Use python 3 style print functions
  * Use the server tags for dimensions and make watch_name optional
  * Add a get_tags() method to the Metadata class
  * Configure Apt to never prompt for user-input
  * Add GitHub tarball and zipball support
  * Fix test cases not running under python 2.6
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Thu Feb 13 2014 speilicke@suse.com
- drop hacking requires, we don't run pep8 tests
* Tue Feb 11 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Sun Jan 19 2014 opensuse-cloud@opensuse.org
- Update to version 1.2.6.6.g2202cfd:
  + Fix logging in cfn-init and cfn-signal
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 1.2.6.4.g8e7c392:
  + Sync with global requirements
* Fri Dec  6 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.6.3.g1d0bf6b:
  + Config files should be non-executable
* Tue Nov 19 2013 speilicke@suse.com
- Run tests locally, therefore merge test package into python module
  package
- Install HTML documentation and man-pages
- Updated (build) requirements
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.6.2.g090a5a9:
  + Add basic yum and apt package install tests
  + Only run yum install once per package block
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.8.ge8d2522:
  + cfn-hup manpage fix s/deamon/daemon typo
  + Use on-demand yum metadata caching in cfn-init
* Tue Sep 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.6.g63d70cd:
  + Implement -k option for cfn-get-metadata
* Mon Sep  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.5.ged5365d:
  + Change cfn-signal option --exit to --exit-code
* Sat Sep  7 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.3.g1a66c0c:
  + Add argparse into requirements
* Sun Aug 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.2.g2044ef2:
  + Support array values in command
* Thu Aug 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.5.1.g5b83c13:
  + Pass cwd and env to test command
* Thu Aug  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.4.7.g01705b8:
  + Use python 3 style print functions
  + Sync with global requirements
* Wed Jul 31 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.4.5.gcfa33e1:
  + Add a get_tags() method to the Metadata class
  + Use the server tags for dimensions and make watch_name optional.
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.4.3.g73cebad:
  + Configure Apt to never prompt for user-input.
* Wed Jul  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.4.2.ga4e7c72:
  + Add GitHub tarball and zipball support
* Thu Jun 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.4.1.g1ad9594:
  + Using pipe to handle tgz sources
  + Fix test cases not running under python 2.6
* Wed Jun 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.3.23.g87e08b0:
  + Add Flake8 checks for bin/cfn-* to Gating
* Thu Jun 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.3.22.g971c165:
  + Delete the temporary directory created by sources handler
* Thu Jun 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.3.21.g70ec26e:
  + Add missing -d option in cfn-signal
* Mon Jun 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.3.20.gbc58e5f:
  + Use Python 3.x compatible octal literals
* Thu Jun 13 2013 dmueller@suse.com
- add missing dependency on boto
* Wed Jun  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.3.19.g2d00ede:
  + cfn-get-metadata: log metadata to standard output
* Tue Jun  4 2013 dmueller@suse.com
- update requires
* Wed May 29 2013 dmueller@suse.com
- remove setBadness call from rpmlintrc
* Mon May  6 2013 dmueller@suse.com
- remove 0001-Restore-Python-2.6-compatibility.patch
- remove 0001-Use-ordereddict-compatibility-for-Python-2.6.patch
* Mon Apr 29 2013 dmueller@suse.com
- add 0001-Use-ordereddict-compatibility-for-Python-2.6.patch
* Mon Apr 29 2013 dmueller@suse.com
- add 0001-Restore-Python-2.6-compatibility.patch
* Fri Apr 26 2013 speilicke@suse.com
- Add test subpackage
- Had to abuse %%{component} since the upstream name and the python install
  dir have different names (sigh).
- Added rpmlintrc
* Mon Apr 22 2013 dmueller@suse.com
- Initial package
